Type Alias PrecompileEthFn
pub type PrecompileEthFn = fn(&[u8], u64) -> Result<EthPrecompileOutput, PrecompileHalt>;Expand description
Eth precompile function type. Takes input and gas limit, returns an Eth precompile result.
This is the function signature used by individual Ethereum precompile implementations.
Use PrecompileFn for the higher-level type that returns PrecompileOutput.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 8 bytes