PrecompileResult

Type Alias PrecompileResult 

pub type PrecompileResult = Result<PrecompileOutput, PrecompileError>;
A precompile operation result type for the precompile provider.

Returns either Ok(PrecompileOutput) or Err(PrecompileError). PrecompileError only represents fatal errors that abort EVM execution.

Aliased Type

pub enum PrecompileResult {
    Ok(PrecompileOutput),
    Err(PrecompileError),
}

Variants

1.0.0

Ok(PrecompileOutput)

Contains the success value

1.0.0

Err(PrecompileError)

Contains the error value

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.